/*

Copyright (C) 2004 Christian Kreibich <christian@whoop.org>.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies of the Software and its documentation and acknowledgment shall be
given in the documentation and software packages that this Software was
used.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/
#ifndef __libnd_mux_h
#define __libnd_mux_h

#include <libnd.h>

/* We need the traceset plugins.
*/
#include <plugins/libnd_traceset.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

typedef enum {
  LND_MUX_MODE_MERGE,     /* Real merge, restoring temporal continuity */
  LND_MUX_MODE_TIMESHIFT, /* Concatenation, adjust start offsets */
  LND_MUX_MODE_CONCAT,    /* Pure concatenation in sequence given */
} LND_MuxMode;

/* Main muxer structure */
typedef struct lnd_mux {
  
  LND_TraceSet      *traces;

  LND_MuxMode        mode;
  gboolean           chron_mode;
  gboolean           verbose;
  gboolean           search_max_caplen;

  int                trace_num;
  
  char              *output_file;
  pcap_t            *output_pcap;
  pcap_dumper_t     *output_dumper;

  int                max_caplen;

  /* For timeshift mode: time at which last trace ended */
  struct bpf_timeval tv;
  guint              delta_secs;
  
} LND_Mux;
  
LND_Mux    *libnd_mux_new(void);
void        libnd_mux_free(LND_Mux *mux);
gboolean    libnd_mux_set_output(LND_Mux *mux, const char *output_file);
void        libnd_mux(LND_Mux *mux);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif
